@@ -62,7 +62,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         self._file.addSeparator()
 
-        self._save = QtWidgets.QAction("Save...")
+        self._save = QtWidgets.QAction("&Save...")
         self._save.triggered.connect(self._save_action)
         self._save.setEnabled(False)
         self._file.addAction(self._save)
@@ -243,7 +243,7 @@ class FRESCO(QtWidgets.QWidget):
 
         j = self.rd.cache.last_object_index
 
-        if j and j < len(self.rd.cat):
+        if j and j < self.rd.n_objects:
             self.load_object(int(j))
         else:
             self.load_object(0)
